Description: bike and bicycle discussion forums.
Keywords: bike forums, bicycle discussion forum, cycling forums

- Register
- Help
- Remember Me?

Advertise on Bikeforums.net

# Bike Forums

Welcome to the Bike Forums.

1. ## Community Connections Threads / Posts Last Post

   1. ## The Official Bike Forums Cafe Press Store

      Our store

   2. ## Introductions

      (1 Viewing)

      Welcome to the BikeForums community! Please introduce yourself to other forum members here.

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 29,672
      - Posts: 121,408

      #### Last Post:

      Hi from Chicago!

      by
      mooncountry

      12-04-14, 01:09 PM

   3. ## Charity Events

      (1 Viewing)

      Whether you're looking for riders, sponsors, or volunteers, this is the place to tell the world that cyclists can make a difference.

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 1,625
      - Posts: 6,345

      #### Last Post:

      22nd Annual Polar Bear -...

      by
      TysonCook

      11-29-14, 08:43 PM

   4. ## Regional Rides and Events

      Do you have a ride for your club, or other organization you need to promote? Feel free for all members to post their events or rides in the appropriate regional Rides Subforum.

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 812
      - Posts: 2,124

      #### Last Post:

      trip to Colorado

      by
      mcallaghan

      12-04-14, 11:16 AM

   5. ## Regional Discussions

      (36 Viewing)

      USA: Northeast - Great Lakes - Southeast - Northern California - Southern California - Pacific Northwest - Hawaii-and-Pacific-Islands-Regional-Forum - Mountain - Plains - Texas - Southwest
      International: Eastern Canada - Western Canada - United Kingdom - Europe - Australia - New Zealand - South America - Africa - Asia

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 34,303
      - Posts: 549,544

      #### Last Post:

      Whittier Greenway Trail

      by
      Rick@OCRR

      12-04-14, 03:02 PM

2. ## Bike Forums Threads / Posts Last Post

   1. ## Adaptive Cycling: Handcycles, Amputee Adaptation, Visual Impairment, and Other Needs

      (1 Viewing)

      Have a need for adaptive equipment to ride to compensate for a disability or loss of limb or function? This area is for discussion among those of us in the cycling world that are coming back from traumatic circumstances and tell the world, "No, you are not going to beat me down!"

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 235
      - Posts: 1,806

      #### Last Post:

      How Many Of You Have A...

      by
      BlindAmbition

      12-01-14, 04:44 PM

   2. ## Advocacy & Safety

      (23 Viewing)

      Cyclists should expect and demand safe accommodation on every public road, just as do all other users. Discuss your bicycle advocacy and safety concerns here.

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 14,266
      - Posts: 472,381

      #### Last Post:

      Ski helmet as bike...

      by
      achoo

      12-04-14, 04:31 PM

   3. ## Alt Bike Culture

      Chopped, dropped, stretched, lifted, and otherwise cut up and put back together. The art and science of choppers, cruisers, lowriders and the vast world of mutant bicycles.

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 1,351
      - Posts: 14,827

      #### Last Post:

      mongoose dolomite on sale

      by
      Philphine

      12-01-14, 05:08 AM

   4. ## Beach Cruisers

      (2 Viewing)

      Do you love balloon tires and fenders? Do you love riding the simplicity of a single gear and coaster brakes or a single gear cluster? Do you love the classic curves in the tubing of a cruiser that takes you back to the 1950's and 1960's, stylistically? Here's your home! Welcome to the Beach Cruisers and Cruisers forum!

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 182
      - Posts: 2,292

      #### Last Post:

      Pedal Recommendations

      by
      fietsbob

      12-04-14, 03:50 PM

   5. ## Bicycle Mechanics

      (177 Viewing)

      Broken bottom bracket? Tacoed wheel? If you're having problems with your bicycle, or just need help fixing a flat, drop in here for the latest on bicycle mechanics & bicycle maintenance.

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 84,415
      - Posts: 807,305

      #### Last Post:

      Brake Pads for Disc...

      by
      jimc101

      12-04-14, 04:19 PM

   6. ## BMX

      (3 Viewing)

      Dirt, vert, flatland or street? Drop in the BMX forum to talk to other 20" riders around the world. What is the best BMX bicycle for you? Learn all about it here.

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 7,277
      - Posts: 105,260

      #### Last Post:

      Honda racing "carve" bmx...

      by
      miamibeachcg

      12-04-14, 01:44 PM

   7. ## Classic & Vintage

      (149 Viewing)

      This forum is to discuss the many aspects of classic and vintage bicycles, including musclebikes, lightweights, middleweights, hi-wheelers, bone-shakers, safety bikes and much more.

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 73,868
      - Posts: 1,311,298

      #### Last Post:

      DT, indexed, brifters,...

      by
      photogravity

      12-04-14, 04:27 PM

   8. ## Classic and Vintage Bicycles: What's it Worth? Appraisals and Inquiries

      (28 Viewing)

      Use this subforum for all requests as to "How much is this vintage bike worth?"Do NOT try to sell it in here, use the Marketplaces.

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 13,034
      - Posts: 99,490

      #### Last Post:

      1993 Bianchi Advantage

      by
      henryha

      12-04-14, 03:48 PM

   9. ## Clydesdales/Athenas (200+ lb / 91+ kg)

      (22 Viewing)

      Looking to lose that spare tire? Ideal weight 200+? Frustrated being a large cyclist in a sport geared for the ultra-light? Learn about the bikes and parts that can take the abuse of a heavier cyclist, how to keep your body going while losing the weight, and get support from others who've been successful.

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 17,825
      - Posts: 318,435

      #### Last Post:

      Post a photo of your...

      by
      CACycling

      12-04-14, 02:08 PM

   10. ## Commuting

       (58 Viewing)

       Bicycle commuting is easier than you think, before you know it, you'll be hooked. Learn the tips, hints, equipment, safety requirements for safely riding your bike to work.

       #### Forum Actions:

       - View this forum's RSS feed

       #### Forum Statistics:

       - Threads: 41,419
       - Posts: 967,136

       #### Last Post:

       Inadvertently Hired a...

       by
       tractorlegs

       12-04-14, 04:30 PM

   11. ## Recreational Cyclocross and Gravelbiking

       (17 Viewing)

       This has to be the most physically intense sport ever invented. It's high speed bicycle racing on a short off road course or riding the off pavement rides on gravel like :The Dirty Kanza". We also have a dedicated Racing forum for the Cyclocross Hard Core Racers.

       #### Forum Actions:

       - View this forum's RSS feed

       #### Forum Statistics:

       - Threads: 6,828
       - Posts: 62,828

       #### Last Post:

       Parts start arriving...

       by
       Number400

       12-04-14, 01:06 PM

   12. ## Electric Bikes

       (7 Viewing)

       Here's a place to discuss ebikes, from home grown to high-tech.

       #### Forum Actions:

       - View this forum's RSS feed

       #### Forum Statistics:

       - Threads: 2,999
       - Posts: 29,852

       #### Last Post:

       Solar Panel for Electric...

       by
       350htrr

       12-04-14, 11:53 AM

   13. ## Electronics, Lighting, & Gadgets

       (18 Viewing)

       HRM, GPS, MP3, HID. Whether it's got an acronym or not, here's where you'll find discussions on all sorts of tools, toys and gadgets.

       #### Forum Actions:

       - View this forum's RSS feed

       #### Forum Statistics:

       - Threads: 6,654
       - Posts: 75,195

       #### Last Post:

       Good $100 or less Blue...

       by
       LGHT

       12-04-14, 03:38 PM

   14. ## Fifty Plus (50+)

       (23 Viewing)

       Share the victories, challenges, successes and special concerns of bicyclists 50 and older. Especially useful for those entering or reentering bicycling.

       #### Forum Actions:

       - View this forum's RSS feed

       #### Forum Statistics:

       - Threads: 22,805
       - Posts: 507,531

       #### Last Post:

       Anyone Else Cliplessless?

       by
       North Coast Joe

       12-04-14, 03:12 PM

   15. ## Fitting Your Bike

       (1 Viewing)

       Are you confused about how you should fit a bike to your particular body dimensions? Have you been reading, found the terms Merxx or French Fit, and dont know what you need? Every style of riding is different- in how you fit the bike to you, and the sizing of the bike itself. Its more than just measuring your height, reach and inseam. With the help of Bike Fitting, youll be able to find the right fit for your frame size, style of riding, and your particular dimensions. Here ya go..the location for everything fit related.

       #### Forum Actions:

       - View this forum's RSS feed

       #### Forum Statistics:

       - Threads: 587
       - Posts: 5,198

       #### Last Post:

       Location of Brake...

       by
       Carbonfiberboy

       12-04-14, 01:22 PM

   16. ## Folding Bikes

       (21 Viewing)

       Discuss the unique features and issues of folding bikes. Also a great place to learn what folding bike will work best for your needs.

       #### Forum Actions:

       - View this forum's RSS feed

       #### Forum Statistics:

       - Threads: 11,292
       - Posts: 159,291

       #### Last Post:

       Titanium Swift frame,...

       by
       porschetoyz

       12-04-14, 03:36 PM

   17. ## Framebuilders

       (9 Viewing)

       Thinking about a custom frame? Lugged vs Fillet Brazed. Different Frame materials? Newvex or Pacenti Lugs? why get a custom Road, Mountain, or Track Frame? Got a question about framebuilding? Lets discuss framebuilding at it's finest.

       #### Forum Actions:

       - View this forum's RSS feed

       #### Forum Statistics:

       - Threads: 3,576
       - Posts: 30,071

       #### Last Post:

       Traditional Method of...

       by
       BenCooper

       12-04-14, 02:00 PM

   18. ## Hybrid Bicycles

       (39 Viewing)

       Where else would you go to discuss these fun, versatile bikes?

       #### Forum Actions:

       - View this forum's RSS feed

       #### Forum Statistics:

       - Threads: 5,182
       - Posts: 76,135

       #### Last Post:

       Trek 730 Multitrack vs...

       by
       Little Darwin

       12-04-14, 03:42 PM

   19. ## Living Car Free

       (5 Viewing)

       Do you live car free or car light? Do you prefer to use alternative transportation (bicycles, walking, other human-powered or public transportation) for everyday activities whenever possible? Discuss your lifestyle here.

       #### Forum Actions:

       - View this forum's RSS feed

       #### Forum Statistics:

       - Threads: 4,709
       - Posts: 140,536

       #### Last Post:

       What you got from BF...

       by
       Jim from Boston

       12-04-14, 04:19 PM

   20. ## Long Distance Competition/Ultracycling, Randonneuring and Endurance Cycling

       (8 Viewing)

       Do you enjoy centuries, double centuries, brevets, randonnees, and 24-hour time trials? Share ride reports, and exchange training, equipment, and nutrition information specific to long distance cycling. This isn't for tours, this is for endurance events cycling

       #### Forum Actions:

       - View this forum's RSS feed

       #### Forum Statistics:

       - Threads: 3,705
       - Posts: 55,914

       #### Last Post:

       Am I kidding myself?

       by
       unterhausen

       12-04-14, 04:26 PM

   21. ## Mountain Biking

       (38 Viewing)

       Mountain biking is one of the fastest growing sports in the world. Check out this forum to discuss the latest tips, tricks, gear and equipment in the world of mountain biking.

       #### Forum Actions:

       - View this forum's RSS feed

       #### Forum Statistics:

       - Threads: 39,440
       - Posts: 474,470

       #### Last Post:

       Ceramic bottom bracket...

       by
       Niblix

       12-04-14, 03:46 PM

   22. ## Professional Cycling For the Fans

       (2 Viewing)

       Follow the Tour de France,the Giro de Italia, the Spring Classics, or other professional cycling races? Here's your home...

       #### Forum Actions:

       - View this forum's RSS feed

       #### Forum Statistics:

       - Threads: 5,037
       - Posts: 112,598

       #### Last Post:

       Professional riders and...

       by
       Wesley36

       12-04-14, 02:35 PM

   23. ## Recreational & Family

       (9 Viewing)

       Ride just to ride? Have a family and want to get them into cycling? Drop in here to discuss recreational and family cycling issues.

       #### Forum Actions:

       - View this forum's RSS feed

       #### Forum Statistics:

       - Threads: 2,818
       - Posts: 26,488

       #### Last Post:

       Post your trailer &...

       by
       oren_hershco

       12-04-14, 01:34 AM

   24. ## Recumbent

       (7 Viewing)

       What IS that thing?! Recumbents may be odd looking, but they have many advantages over a "wedgie" bicycle. Discuss the in's and out's recumbent lifestyle in the recumbent forum.

       #### Forum Actions:

       - View this forum's RSS feed

       #### Forum Statistics:

       - Threads: 4,126
       - Posts: 44,801

       #### Last Post:

       Lightning F-40

       by
       delcrossv

       12-04-14, 09:14 AM

   25. ## Road Cycling

       (177 Viewing)

       It is by riding a bicycle that you learn the contours of a country best, since you have to sweat up the hills and coast down them. Thus you remember them as they actually are, while in a motor car only a high hill impresses you, and you have no such accurate remembrance of country you have driven through as you gain by riding a bicycle. Ernest Hemingway.

       #### Forum Actions:

       - View this forum's RSS feed

       #### Forum Statistics:

       - Threads: 145,613
       - Posts: 3,217,123

       #### Last Post:

       Unstable Ti bike. ...

       by
       bt

       12-04-14, 04:28 PM

   26. ## Singlespeed & Fixed Gear

       (89 Viewing)

       "I still feel that variable gears are only for people over forty-five. Isn't it better to triumph by the strength of your muscles than by the artifice of a derailer? We are getting soft...As for me, give me a fixed gear!"--[Henri Desgrange (31 January 1865 - 16 August 1940) ]

       #### Forum Actions:

       - View this forum's RSS feed

       #### Forum Statistics:

       - Threads: 53,054
       - Posts: 1,404,507

       #### Last Post:

       What Else Did You Just...

       by
       Scrodzilla

       12-04-14, 04:22 PM

   27. ## Fixed Gear Freestyle

       (2 Viewing)

       Trickbikes and Freestylers, here's your home! Here, you can discuss the ins and outs of building and riding these bikes.

       #### Forum Actions:

       - View this forum's RSS feed

       #### Forum Statistics:

       - Threads: 87
       - Posts: 1,269

       #### Last Post:

       Best frame for custom...

       by
       PithyBikes

       11-27-14, 04:36 PM

   28. ## Tandem Cycling

       (7 Viewing)

       A bicycle built for two. Want to find out more about this wonderful world of tandems? Check out this forum to talk with other tandem enthusiasts. Captains and stokers welcome!

       #### Forum Actions:

       - View this forum's RSS feed

       #### Forum Statistics:

       - Threads: 7,126
       - Posts: 82,833

       #### Last Post:

       X-12 through axle

       by
       twocicle

       12-04-14, 04:15 PM

   29. ## Touring

       (57 Viewing)

       Have a dream to ride a bike across your state, across the country, or around the world? Self-contained or fully supported? Trade ideas, adventures, and more in our bicycle touring forum.

       #### Forum Actions:

       - View this forum's RSS feed

       #### Forum Statistics:

       - Threads: 25,321
       - Posts: 354,292

       #### Last Post:

       Colorado Loop

       by
       andrewclaus

       12-04-14, 04:29 PM

   30. ## Training & Nutrition

       (18 Viewing)

       Learn how to develop a training schedule that's good for you. What should you eat and drink on your ride? Learn everything you need to know about training and nutrition here.

       #### Forum Actions:

       - View this forum's RSS feed

       #### Forum Statistics:

       - Threads: 11,656
       - Posts: 138,169

       #### Last Post:

       Training plan for former...

       by
       corrado33

       12-04-14, 01:58 PM

   31. ## Triathlon

       (3 Viewing)

       Swim / Bike / Run your thing? Drop in our new triathlon forum for the latest in training & gear. From beginner to expert, and sprint to ironman.

       #### Forum Actions:

       - View this forum's RSS feed

       #### Forum Statistics:

       - Threads: 4,050
       - Posts: 31,077

       #### Last Post:

       question about time...

       by
       principia 650

       12-03-14, 08:31 AM

   32. ## Utility Cycling

       (7 Viewing)

       Want to haul groceries, beer, maybe even your kids? You don't have to live car free to put your bike to use as a workhorse. Here's the place to share and learn about the bicycle as a utility vehicle.

       #### Forum Actions:

       - View this forum's RSS feed

       #### Forum Statistics:

       - Threads: 2,468
       - Posts: 35,728

       #### Last Post:

       low top tube, or step...

       by
       superpants

       12-03-14, 04:47 PM

   33. ## Winter Cycling

       (12 Viewing)

       Don't let snow and ice discourage you this winter. The key element to year-round cycling is proper attire! Check out this winter cycling forum to chat with other ice bike fanatics.

       #### Forum Actions:

       - View this forum's RSS feed

       #### Forum Statistics:

       - Threads: 3,905
       - Posts: 50,073

       #### Last Post:

       45 North or Dogwood...

       by
       revcp

       12-04-14, 04:13 PM

   34. ## General Cycling Discussion

       (53 Viewing)

       Have a cycling related question or comment that doesn't fit in one of the other specialty forums? Drop on in and post in here! When possible, please select the forum above that most fits your post!

       #### Forum Actions:

       - View this forum's RSS feed

       #### Forum Statistics:

       - Threads: 33,034
       - Posts: 440,000

       #### Last Post:

       Kryptonite NY ulock...

       by
       GP

       12-04-14, 03:36 PM

3. ## The Racer's Forum Threads / Posts Last Post

   Race Bicycles? This is the place for you. Contents include Road Racing | Masters Road Racing | Mountainbike | Cyclocross Racing | This Category is for the racers, themselves, and future racers. Discussions of the big races from the spectator side should be posted in our Pro Cycling for the Fans Forum

   1. ## "The 33"-Road Bike Racing

      (15 Viewing)

      We set this forum up for our members to discuss their experiences in either pro or amateur racing, whether they are the big races, or even the small backyard races. Don't forget to update all the members with your own race results.

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 15,268
      - Posts: 550,483

      #### Last Post:

      Racer Tech Thread

      by
      rkwaki

      12-04-14, 03:41 PM

   2. ## Juniors Racing (All Disciplines)

      Entry level and/or 23 and younger here's where yo can mix and learn.

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 47
      - Posts: 597

      #### Last Post:

      Should my son sign up...

      by
      Doge

      11-24-14, 08:42 AM

   3. ## Masters Racing (All Disciplines)

      Race on the track or road or on your mountainbike in the Masters Category? Want to talk tactics, strategy and training with your peers?

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 104
      - Posts: 22,543

      #### Last Post:

      Race Rigs - Show us your...

      by
      Allegheny Jet

      12-04-14, 04:14 PM

   4. ## Cyclocross Racing

      (3 Viewing)

      Discuss pro racing, the big races, and even the small backyard races. Don't forget to update all the members with your own race results.

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 685
      - Posts: 7,911

      #### Last Post:

      Bunnyhop Takedown! Fair,...

      by
      kimpw

      12-03-14, 02:00 PM

   5. ## Mountain Bike Racing

      Discuss pro racing, the big races, and even the small backyard races. Don't forget to update all the members with your own race results.

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 596
      - Posts: 3,889

      #### Last Post:

      longer midwest races

      by
      drider85

      11-13-14, 03:51 PM

   6. ## Track Cycling: Velodrome Racing and Training Area

      (10 Viewing)

      Looking to enter into the realm of track racing? Want to share your experiences and tactics for riding on a velodrome? The Track Cycling forums is for you! Come in and discuss training/racing, equipment, and current track cycling events.

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 2,504
      - Posts: 32,123

      #### Last Post:

      Interesting finds around...

      by
      Quinn8it

      12-04-14, 03:46 PM

4. ## Products and Services Threads / Posts Last Post

5. ## The Market Place Threads / Posts Last Post

   The Marketplace requires Premium Membership to post new threads. This can be purchased at: http://www.bikeforums.net/payments.php bikeforums.net only provides infrastructure and a platform for your sale threads and assumes no responsibility for the transactions or disputes. This applies to all Marketplaces and For Trade threads.

   1. ## For Sale

      (1 Viewing)

      Items for sale, bicycle and cycling related items only, please! Requires upgraded Membership to post new threads. This forum is intended for individual members to sell their bikes and bike related gear, and not for commercial ventures or company sales. Prices must be quoted up front, we are not an auction site, and do not link to your ebay auctions.

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 49
      - Posts: 1,904

      #### Last Post:

      WTS: Twin Six "Masher"...

      by
      Johnny Rad

      12-03-14, 08:36 PM

   2. ## Group Buy

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 1
      - Posts: 1

      #### Last Post:

      Group Buys Guidelines

      by
      lotek

      06-10-08, 12:21 PM

   3. ## Want To Buy

      Looking to buy bicycle related gear? Post your request here. Requires upgraded membership to post new threads

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 6
      - Posts: 27

      #### Last Post:

      Looking for a 1986-87?...

      by
      RiseAlways

      12-03-14, 01:38 PM

   4. ## Cycling Related Job Postings: Help Wanted

      Need to hire a mechanic or sales person for your bike shop? Looking to hire bike messengers? Post your cycling jobs you have available in here.

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 5
      - Posts: 5

      #### Last Post:

      Private

   5. ## Cycling Related Jobs: Employment Wanted

      Are you a Bike Mechanic looking for a job? Are you a Bike Messenger, or looking for a job in the industry? Post here to express you interest! This subforum is open to all registered and upgraded members as a service of Bike Forums. Good luck in your search and never give up!

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 1
      - Posts: 1

      #### Last Post:

      Welcome to the Cycling...

      by
      Tom Stormcrowe

      07-17-09, 08:40 AM

6. ## The Lounge Threads / Posts Last Post

   1. ## Chat Room

   2. ## Foo

      (25 Viewing)

      Off-Topic chit chat with no general subject.

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 38,643
      - Posts: 1,382,096

      #### Last Post:

      I'm broke, I need more...

      by
      fietsbob

      12-04-14, 03:59 PM

   3. ## Blogger's Forum

      Whether it's a cycling blog, or just your personal page, this is the place to share ideas and links.

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 521
      - Posts: 2,359

      #### Last Post:

      Blog? Why Blog when you...

      by
      LesMcLuffLots

      12-02-14, 05:15 PM

   4. ## Books, Movies, Music & Entertainment

      Do we really need a description for this forum?

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 40
      - Posts: 10,423

      #### Last Post:

      My top ten list - guitar...

      by
      spectastic

      12-02-14, 10:05 AM

   5. ## Jokes & Humor

      (1 Viewing)

      Life sucks without humor. Post your best (and worst) jokes here.

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 34
      - Posts: 248

      #### Last Post:

      Blonde Jokes

      by
      FLJeepGuy

      12-03-14, 08:59 AM

7. ## News & Suggestions Threads / Posts Last Post

   1. ## News & Announcements

      (1 Viewing)

      Recall Announcements
      Get up to date News about the BikeForums Community here.

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 189
      - Posts: 2,531

      #### Last Post:

      Felt cyclocross bicycles

      by
      johnny99

      12-02-14, 05:27 PM

   2. ## Forum Suggestions & User Assistance

      (2 Viewing)

      Have a suggestion for the forums? Need help with the Forums? Post here.

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 3,008
      - Posts: 22,051

      #### Last Post:

      how much does the forum...

      by
      Tom Stormcrowe

      12-03-14, 10:53 PM

   3. ## Manufacturer, Retailer, Survey and Consumer Feedback

      As a manufacturer or retailer, do you want opinions and feedback on your products or services? Members, do you have an open letter to publish? Here's a place for both sides of the industry to communicate. Also, surveys and Student Data Colllection projects go in here.

      #### Forum Actions:

      - View this forum's RSS feed

      #### Forum Statistics:

      - Threads: 78
      - Posts: 528

      #### Last Post:

      Survey on Bike Helmets

      by
      niteshkw

      11-25-14, 04:16 PM

   4. ## Forum Leaders

Mark Forums Read | View Forum Leaders

## What's Going On?

### Currently Active Users

There are currently 1385 users online. 215 members and 1170 guests

Most users ever online was 4,142, 06-10-13 at 11:49 AM.

1. 350htrr,
2. 64Dunelt,
3. 79pmooney,
4. achoo,
5. Acquaspin,
6. aixaix ,
7. amdoo,
8. american psycho ,
9. andrewclaus,
10. Andy STi,
11. AnthonyG,
12. Archwhorides,
13. arctos,
14. AristoNYC,
15. atbman,
16. axolotl,
17. Bag302,
18. Bandera ,
19. benlees,
20. bgoodwin,
21. bhchdh ,
22. Bianchigirll ,
23. bicyclebradley,
24. bikemig ,
25. Bikes and Jeeps,
26. bikingshearer ,
27. BilbroSwaggins,
28. BluePx10,
29. bobonker ,
30. boingtay,
31. BoSoxYacht,
32. bt,
33. cafzali,
34. Canker,
35. Capt_Sensible,
36. carleton,
37. catsnapper,
38. cbhungry,
39. chewybrian ,
40. cleansheet,
41. coolcamaro12,
42. corrado33,
43. CrankyOne,
44. CroMo Mike,
45. CTAC,
46. CTMike,
47. dannwilliams ,
48. Dawes-man,
49. dbruening80,
50. delcrossv ,
51. DGoodrow,
52. dharleyd,
53. Doug64,
54. dstrong ,
55. dtrain,
56. dubes ,
57. dubjay,
58. Dunbar,
59. echappist ,
60. EDDAKA,
61. Edonis13,
62. erig007,
63. eschlwc,
64. Fastfwd01,
65. FBinNY ,
66. fietsbob ,
67. finntog,
68. Fishmonger,
69. furiousferret ,
70. gaucho777 ,
71. Gawain68,
72. GENESTARWIND,
73. GGreenhorn,
74. GhostSS,
75. Giacomo 1 ,
76. goenrdoug,
77. gomango ,
78. Grand Bois,
79. grolby,
80. gugie,
81. hamster ,
82. hank0604,
83. herbincj,
84. hochflynn,
85. hyegeek,
86. IANJING,
87. icepick_trotsky ,
88. irwin7638,
89. ivorydan,
90. Jack Daniel,
91. james2134,
92. jasii,
93. jet sanchEz,
94. JGAN,
95. Jim from Boston,
96. jimc101,
97. jkretsch,
98. JoeyBike,
99. Johnny 831,
100. jsharr,
101. Jumpjet,
102. justin1138,
103. Kaminokaze,
104. keifer,
105. Keith99,
106. KonAaron Snake ,
107. kpfeif,
108. kylecycler,
109. Latif,
110. leegf,
111. LesterOfPuppets,
112. Lew.,
113. LGHT,
114. likebike23 ,
115. lookinUp ,
116. LordHelmet,
117. lostarchitect ,
118. luukoutbelow,
119. LWaB,
120. m3rle,
121. Mac Attack 34,
122. mconlonx ,
123. mechanicmatt,
124. mellowbob,
125. modernjess,
126. Monkey D.Luffy,
127. moochems ,
128. mukman,
129. Narhay,
130. nemeseri,
131. nesteel ,
132. never_recover,
133. New_IA_Rider,
134. nickw,
135. nightfly,
136. nlerner,
137. no motor?,
138. noisebeam,
139. non-fixie ,
140. North Coast Joe,
141. oddjob2 ,
142. pepot,
143. pizzamania,
144. Ravenhog,
145. rekknr,
146. rellis,
147. Rick@OCRR,
148. ricklp ,
149. RiseAlways ,
150. rlp,
151. RoadGuy,
152. Rocky Gravol,
153. Rogan,
154. Ronno6,
155. rpenmanparker ,
156. rwci_1,
157. Saguaro,
158. save10,
159. Scooper,
160. SirHustlerEsq,
161. squirtdad,
162. ssseeee,
163. stemark,
164. Stev8del8,
165. supe1,
166. Telly,
167. Terpdevil,
168. the sci guy ,
169. thisisbenji,
170. timmy29er,
171. tjk23 ,
172. toddles,
173. tommyblair22,
174. tony99,
175. top506,
176. tractorlegs,
177. triumph.man,
178. trsidn ,
179. truckface ,
180. twocicle,
181. Velocivixen,
182. VictorKnox,
183. vijinho,
184. Vintage_Cyclist,
185. vze23c3q,
186. w0lffian,
187. Walter S,
188. Wanderer,
189. WhyFi,
190. wide45,
191. Wileyrat,
192. windhchaser ,
193. wrk101,
194. wrpeterson,
195. yankeefan,
196. yuoil ,
197. Zinger

### Today's Birthdays

1. NZLcyclist (28)

### Bike Forums Statistics

Threads
  898,088
Posts
  16,534,647
Members
  294,889
Active Members
  10,212

Welcome to our newest member, Woochifer

### Icon Legend

  Contains unread forum posts
  Contains no unread forum posts
  Forum is a category
  Forum is a Link